"use strict";
/**
 * @file heap.ts
 * @description
 * @author Dushan Ranasinghage
 * @copyright Copyright 2023 Dushan Ranasinghage, Alright Reserved.
 */
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Heap sort algorithm
 *
 * @name heapSort
 * @since  1.0.0
 * @access  public
 *
 * @property {T[]} arr Any type of array.
 */
function heapSort(arr) {
    buildMaxHeap(arr);
    for (let i = arr.length - 1; i > 0; i--) {
        // Swap root (maximum value) with the last element
        [arr[0], arr[i]] = [arr[i], arr[0]];
        // Heapify the reduced heap
        heapify(arr, i, 0);
    }
    return arr;
}
function buildMaxHeap(arr) {
    const length = arr.length;
    const startIndex = Math.floor(length / 2) - 1;
    for (let i = startIndex; i >= 0; i--) {
        heapify(arr, length, i);
    }
}
function heapify(arr, length, rootIndex) {
    let largestIndex = rootIndex;
    const leftChildIndex = 2 * rootIndex + 1;
    const rightChildIndex = 2 * rootIndex + 2;
    if (leftChildIndex < length && arr[leftChildIndex] > arr[largestIndex]) {
        largestIndex = leftChildIndex;
    }
    if (rightChildIndex < length && arr[rightChildIndex] > arr[largestIndex]) {
        largestIndex = rightChildIndex;
    }
    if (largestIndex !== rootIndex) {
        // Swap root with the largest element
        [arr[rootIndex], arr[largestIndex]] = [arr[largestIndex], arr[rootIndex]];
        // Recursively heapify the affected sub-tree
        heapify(arr, length, largestIndex);
    }
}
exports.default = heapSort;
